==> peperit_2.0_estable.zip: themes/peperit/html_files/condiciones_venta.php <==
﻿<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Aviso legal
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
?>

<?php
// Incluimos la miga
//escupirMiga("Aviso legal");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Condiciones de venta', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">
               <h3 class="page-subheading"><?=traducir('CONDICIONES DE COMPRA');?></h3>
                <p><?=traducir('%-Shop::$empresa->nombre_legal-%, con domicilio en %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-% %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%) y con N.I.F. %-Shop::$empresa->cif-% es la propietaria de la página web %-Shop::$configuracion->url-% (en adelante la Web) y la pone a disposición de los usuarios de Internet, con el fin tanto de proporcionar información sobre los productos que se ofrecen, como de permitir la adquisición de los mismos a través del portal.');?></p>

                <p><?=traducir('Estas Condiciones de Uso y Venta establecen los derechos y obligaciones de los usuarios de la web %-Shop::$configuracion->url-% en relación con los productos que se ofertan en la tienda online y representan un contrato vinculante entre ambas partes. Pueden ser modificadas o actualizadas sin previo aviso, por lo que deben leerse previamente a la realización del pedido.');?></p>

                <h3 class="page-subheading"><?=traducir('1.- Formas de pago.');?></h3>
                <p><strong><?=traducir('Transferencia bancaria');?></strong></p>
                <p><strong><?=traducir('Al escoger la opción de pago y al finalizar el proceso de compra se indica un número de cuenta al que efectuar la transferencia. En el concepto se indicará el número de pedido o el nombre y apellidos del comprador.');?><?= traducir(' Una vez realizada la transferencia, el envío se realizará tras comprobar la misma, por lo que recomendamos enviar el justificante del pago a %-Shop::$empresa->email_empresa-% para agilizar el envío. Los pagos por transferencia han de formalizarse en un plazo máximo de 72 horas tras la realización del pedido. Superado este plazo, el pedido queda anulado.');?></strong></p>
                <p><?=traducir('Cuando finalice el pedido, en el email de confirmación de pedido aparecerá la cuenta bancaria donde deben hacer efectivo el pago.');?></p>

                <p><strong><?=traducir('Tarjeta de crédito o débito Visa/Mastercad');?></strong></p>
                <p><?=traducir('Se puede realizar el pago con tarjeta mediante la pasarela de pago seguro.');?></p>

                
                <h3 class="page-subheading"><?=traducir('2.- Envíos y Plazos de entrega.');?></h3>
                <p><?=traducir('Los gastos de envío pueden variar en función de la localidad a la que se envíe y del importe de la cesta. Estos cálculos los realizará la cesta de la compra automáticamente sin necesidad de intervención por parte del usuario. Solo tendrá que rellenar sus datos en el caso en el que seleccione método de envío a domicilio.');?> </p>
               
                                
                <h3 class="page-subheading"><?=traducir('3.- Devoluciones y cambios.');?></h3>
                <p><?=traducir('Para la realización de una devolución de un producto con el que no estás satisfecho (excluyendo libros) tienes un plazo de 14 días desde la fecha de entrega. Para que te sea reembolsado, debes enviar un mail a %-Shop::$empresa->email_empresa-% o llamar al %-Shop::$empresa->telefono_empresa-% indicando el motivo de la devolución y te indicaremos el procedimiento para el envío de vuelta del producto. El producto o productos deben cumplir lo siguiente:');?></p>
                <ul>
                    <li><?=traducir('- Estar en perfecto estado, conservando su etiquetaje y embalaje original.');?></li>
                    <li><?=traducir('- Enviarse de vuelta de manera análoga a como se ha recibido, siempre protegiendo el embalaje.');?></li>
                </ul>
                <p><?=traducir('Cuando recibamos el paquete y comprobemos que está en buenas condiciones, reintegraremos el importe a la cuenta bancaria que indiques en un plazo máximo de 7 días, descontando los gastos del envío ocasionados.');?></p>
                
                <p><?=traducir('Los costes de envío de la devolución corren a cargo del cliente, incluso si en la compra original hubieran sido gratuitos, a no ser que se trate de una devolución por defectos en la mercancía o error en el envío. En este caso, no dudes en llamar o escribir un mail para avisar de este hecho y que te cambiemos el producto sin coste de envío para ti.');?></p>

                <p><?= traducir('Si al recibir el paquete observaras que está dañado por causa del transporte, debes indicarlo en el albarán que te entrega el transportista y contactar en el teléfono %-Shop::$empresa->telefono_empresa-% o en el %-Shop::$empresa->email_empresa-% en las 24 horas siguientes a su recepción, para que pueda hacer la reclamación oportuna. La sustitución se realizará sin coste para ti. O si prefieres cancelar el pedido, se descontarían los gastos de envío y de recogida.');?></p>
                <div class="volver">
                </div>
            </article>
        </div>
    </div>
</section>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/condiciones_venta.php <==
﻿<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Aviso legal
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
?>
<?php
//Marina (18/08/2020) comparo localidad y provincia para ver si son iguales, si es así una la dejo vacía.
$localidad = Shop::$empresa->localidad;
$provincia = Shop::$empresa->provincia;
if(strtolower($localidad) == strtolower($provincia)){
    $localidad ='';
}else{
     $localidad .=',';
}
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Condiciones de venta', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">
               <h3 class="page-subheading"><?=traducir('CONDICIONES DE COMPRA');?></h3>
                <p><?=traducir('%-Shop::$empresa->nombre_legal-%, con domicilio en %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-%,');?><?=$localidad . $provincia;?><?=traducir(' y con N.I.F. %-Shop::$empresa->cif-% es la propietaria de la página web %-Shop::$configuracion->url-% (en adelante la Web) y la pone a disposición de los usuarios de Internet, con el fin tanto de proporcionar información sobre los productos que se ofrecen, como de permitir la adquisición de los mismos a través del portal.');?></p>

                <p><?=traducir('Estas Condiciones de Uso y Venta establecen los derechos y obligaciones de los usuarios de la web %-Shop::$configuracion->url-% en relación con los productos que se ofertan en la tienda online y representan un contrato vinculante entre ambas partes. Pueden ser modificadas o actualizadas sin previo aviso, por lo que deben leerse previamente a la realización del pedido.');?></p>

                <h3 class="page-subheading"><?=traducir('1.- Formas de pago.');?></h3>
                <p><strong><?=traducir('Transferencia bancaria');?></strong></p>
                <p><strong><?=traducir('Al escoger la opción de pago y al finalizar el proceso de compra se indica un número de cuenta al que efectuar la transferencia. En el concepto se indicará el número de pedido o el nombre y apellidos del comprador.');?><?= traducir(' Una vez realizada la transferencia, el envío se realizará tras comprobar la misma, por lo que recomendamos enviar el justificante del pago a %-Shop::$empresa->email_empresa-% para agilizar el envío. Los pagos por transferencia han de formalizarse en un plazo máximo de 72 horas tras la realización del pedido. Superado este plazo, el pedido queda anulado.');?></strong></p>
                <p><?=traducir('Cuando finalice el pedido, en el email de confirmación de pedido aparecerá la cuenta bancaria donde deben hacer efectivo el pago.');?></p>

                <p><strong><?=traducir('Tarjeta de crédito o débito Visa/Mastercad');?></strong></p>
                <p><?=traducir('Se puede realizar el pago con tarjeta mediante la pasarela de pago seguro.');?></p>

                
                <h3 class="page-subheading"><?=traducir('2.- Envíos y Plazos de entrega.');?></h3>
                <p><?=traducir('Los gastos de envío pueden variar en función de la localidad a la que se envíe y del importe de la cesta. Estos cálculos los realizará la cesta de la compra automáticamente sin necesidad de intervención por parte del usuario. Solo tendrá que rellenar sus datos en el caso en el que seleccione método de envío a domicilio.');?> </p>
               
                                
                <h3 class="page-subheading"><?=traducir('3.- Devoluciones y cambios.');?></h3>
                <p><?=traducir('Para la realización de una devolución de un producto con el que no estás satisfecho (excluyendo libros) tienes un plazo de 14 días desde la fecha de entrega. Para que te sea reembolsado, debes enviar un mail a %-Shop::$empresa->email_empresa-% o llamar al %-Shop::$empresa->telefono_empresa-% indicando el motivo de la devolución y te indicaremos el procedimiento para el envío de vuelta del producto. El producto o productos deben cumplir lo siguiente:');?></p>
                <ul>
                    <li><?=traducir('- Estar en perfecto estado, conservando su etiquetaje y embalaje original.');?></li>
                    <li><?=traducir('- Enviarse de vuelta de manera análoga a como se ha recibido, siempre protegiendo el embalaje.');?></li>
                </ul>
                <p><?=traducir('Cuando recibamos el paquete y comprobemos que está en buenas condiciones, reintegraremos el importe a la cuenta bancaria que indiques en un plazo máximo de 7 días, descontando los gastos del envío ocasionados.');?></p>
                
                <p><?=traducir('Los costes de envío de la devolución corren a cargo del cliente, incluso si en la compra original hubieran sido gratuitos, a no ser que se trate de una devolución por defectos en la mercancía o error en el envío. En este caso, no dudes en llamar o escribir un mail para avisar de este hecho y que te cambiemos el producto sin coste de envío para ti.');?></p>

                <p><?= traducir('Si al recibir el paquete observaras que está dañado por causa del transporte, debes indicarlo en el albarán que te entrega el transportista y contactar en el teléfono %-Shop::$empresa->telefono_empresa-% o en el %-Shop::$empresa->email_empresa-% en las 24 horas siguientes a su recepción, para que pueda hacer la reclamación oportuna. La sustitución se realizará sin coste para ti. O si prefieres cancelar el pedido, se descontarían los gastos de envío y de recogida.');?></p>
                <div class="volver">
                </div>
            </article>
        </div>
    </div>
</section>
